# coding: utf-8
import json
import os
import os.path
import tempfile


def load_headers(path, suffix='.json'):
    headers = {}
    try:
        with open(path + suffix) as infile:
            headers = json.load(infile)
    except:
        pass
    return headers


def save_headers(response, path, suffix='.json'):
    headers = {}
    if 'Last-Modified' in response.headers:
        headers['If-Modified-Since'] = response.headers['Last-Modified']
    if 'ETag' in response.headers:
        headers['If-None-Match'] = response.headers['ETag']
    if headers:
        with open(path + suffix, 'w') as outfile:
            json.dump(headers, outfile, indent=4)


def save_file(response, save_path):
    if os.path.isfile(save_path):
        with tempfile.NamedTemporaryFile(delete=False) as fd:
            store(response, fd)
        os.rename(fd.name, save_path)
    else:
        with open(save_path, 'wb') as fd:
            store(response, fd)


def store(response, fd):
    for chunk in response.iter_content(512):
        fd.write(chunk)
